#
# spec file for package sap-locale
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sap-locale
AutoReq:        on
Version:        1.0
Release:        93.5
Summary:        SAP-specific Locales
License:        GPL-2.0+ and LGPL-2.0+
Group:          System/Libraries
Url:            http://www.novell.com/partners/sap/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         %{name}.tar.gz
Source1:        baselibs.conf
ExclusiveArch:  %{ix86} ia64 ppc64 ppc64le s390x x86_64
BuildRequires:  glibc-i18ndata
BuildRequires:  glibc-locale
Requires:       glibc-locale
Obsoletes:      saplocales
Provides:       saplocales
Requires(post): coreutils
Requires(post): sed
Requires(postun): coreutils
Requires(postun): sed
%if 0%{?suse_version} > 1320
# Needed for reference to __gconv_transliterate
%define __filter_GLIBC_PRIVATE 1
%endif

%description 
This package contains all the SAP specific locales needed for running
an SAP Application Server.

The SAP applications were originally written at a time when the
standards for various locales were either not defined at all or were
not in wide usage yet before the release of the SAP applications.

Consequently, there now exists a divergency between the needs of the
SAP applications running under Linux and what is being supplied via the
GNU C Library Locales, which follows the current standards for the
various defined locales.

In order to be able to use SAP applications under SUSE Linux (and
especially under SUSE Linux Enterprise Server (SLES)), Novell is
supplying this package which contains the legacy locales required for
the SAP applications. The detailed list of locales is provided in
package documentation. These locales can coexist with the standard
locales on your system.

%prep
%setup -n sap-locale

%build
echo "_libdir = '%{_libdir}'  _lib = '%{_lib}'"
make

%install
# Create all needed infrastructure directories
for dir in %{_prefix}/share/locale/locale.alias.d %{_prefix}/lib/locale %{_libdir}/gconv; do
	install -d -m 755 ${RPM_BUILD_ROOT}${dir}
done
# Install all native modules and files for all architectures
install -m 444 locale.alias.SAP ${RPM_BUILD_ROOT}%{_prefix}/share/locale/locale.alias.d/SAP
cp -a locale/ ${RPM_BUILD_ROOT}%{_prefix}/lib/
cp -a gconv/ ${RPM_BUILD_ROOT}/%{_libdir}/

%clean
rm -rf ${RPM_BUILD_ROOT}

%post
for l in /usr/share/locale/locale.alias %{_libdir}/gconv/gconv-modules; do
	# Regenerate the file - strip all below the autogen delimiter, then
	# restore the autogen part based on new contents
	sed -i -e '/^###X# /Q' "$l"
	echo "###X# The following is autogenerated from extra files in the .d directory:" >>"$l"
	cat "$l.d"/* >>"$l"
done
iconvconfig

%postun
for l in /usr/share/locale/locale.alias %{_libdir}/gconv/gconv-modules; do
	# Regenerate the file - strip all below the autogen delimiter, then
	# restore the autogen part based on new contents
	sed -i -e '/^###X# /Q' "$l"
	[ -d "$l.d" ] || continue 
	echo "###X# The following is autogenerated from extra files in the .d directory:" >>"$l"
	cat "$l.d"/* >>"$l"
done
iconvconfig

%files 
%defattr(444, root, root, 755)
%doc COPYING
%doc COPYING.LIB
%doc README
%{_prefix}/lib/locale/*
%{_libdir}/gconv/*
%{_prefix}/share/locale/locale.alias.d
%{_prefix}/share/locale/locale.alias.d/SAP

%changelog
* Mon Jun 29 2015 schwab@suse.de
- Handle old style transliteration step
* Tue Mar 31 2015 schwab@suse.de
- Merge updates from glibc
- Filter out GLIBC_PRIVATE reference to __gconv_transliterate
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in post script
* Tue Dec 10 2013 dvaleev@suse.com
- enable ppc64le
* Tue Mar  5 2013 coolo@suse.com
- update license to new format
* Tue Jan 26 2010 pbaudis@suse.cz
- fix the previous change to have provides/obsoletes only in the -32bit
  subpackage
* Mon Jan 25 2010 pbaudis@suse.cz
- account for ia64 32bit package name change -32bit -> -x86
* Wed Jan 20 2010 ro@suse.de
- re-add baselibs.conf
* Mon Jan 11 2010 mcihar@suse.cz
- call iconvconfig in pre/post inst [bnc#445636]
* Fri Nov 20 2009 pbaudis@suse.cz
- Use a delimiter-based method for proper maintenance of the custom
  entries in glibc-owned files.
- Remove random $Id$ remnants scattered around.
- Add SJIS -> SAPSJIS gconv alias. [bnc#402705,bnc#445634]
* Thu Nov 12 2009 pbaudis@suse.cz
- PreReq coreutils for the %%post script
* Mon Nov  9 2009 pbaudis@suse.cz
- Use the locale.alias.d/ and gconv-modules.d/ mechanism to provide
  custom entries in these files. [bnc#445636]
* Tue Sep 22 2009 mcihar@suse.cz
- Fix upper case conversion in tr_TR. [bnc#513940,bnc#513945]
- Added sk_SK.iso88592@SAP, similar to cs_CZ one. [bnc#513950,bnc#513952]
- Adjusted upper case handling in de_DE. [bnc#513940,bnc#513945]
* Sat Mar  7 2009 pbaudis@suse.cz
- Correct gconv-32 installation on ia64
- Introduce SAPSJIS.so charset conversion support
- Introduce ja_JP.SAPSJIS, with extra 0xExxx characters
* Wed Feb 13 2008 ro@suse.de
- use baselibs.conf instead of specfile magic
- simplify specfile
* Mon Jan 21 2008 pbaudis@suse.cz
- Introduce cs_CZ.iso88592@SAP, sorting numbers before letters
* Fri Dec 21 2007 pbaudis@suse.cz
- Fix de_DE and ko_KR locale names to contain valid codeset part
* Mon Nov 19 2007 pbaudis@suse.cz
- Real de_DE.iso88591HP@SAP support
- -32bit package fixes
* Fri Nov  2 2007 pbaudis@suse.cz
- Version 1.0
- Initial creation of package by DOlsson@novell.com and pbaudis@suse.cz
